/**
 * WhatsApp Chat - Javascript
 * 
 * WhatsApp Chat Block
 * 
 * @copyright 2016 SCHLIX Web Inc
 *
 * @license MIT
 *
 * @package whatsappchat
 * @version 1.0
 * @author  SCHLIX Web Inc <info@schlix.com>
 * @link    http://www.schlix.com
 */

SCHLIX.CMS_WhatsAppChat = class
{
    /**
     * Constructor
     */

    constructor()
    {

        var block_cookie_name = 'whatsappchat_showblock';
        var block_cookie_value = SCHLIX.Cookie.get(block_cookie_name);
        if (isNaN(block_cookie_value) || block_cookie_value == null)
        {
            SCHLIX.Cookie.remove(block_cookie_name);
            SCHLIX.Cookie.set(block_cookie_name, -2, {path: "/"});
        }     
        this.toggleControl('',   'whatsappchat_showhide',   'whatsappchat-bar', true);
        SCHLIX.Event.on('whatsappchat-btn-close','click', this.toggleShowBar, this, true);
        SCHLIX.Event.on('whatsappchat-btn-open','click', this.toggleShowBar, this, true);
        SCHLIX.Event.on('whatsappchat-btn-send','click', this.sendWhatsAppMessage, this, true);

    };

    /**
     * Toggle the control
     * @param {string} indicator_id
     * @param {string} cookie_name
     * @param {string} container_class
     * @param {bool} first_set
     * @returns {unresolved}
     */
    toggleControl(indicator_id, cookie_name, container_class, first_set)
    {
        var cookie_value = parseInt(SCHLIX.Cookie.get(cookie_name), 10);    
        var indicator = SCHLIX.Dom.get(indicator_id);  
        
        if (isNaN(cookie_value) || cookie_value === null)    
        {        
            cookie_value = -2;
        }
        if (!first_set)
        {            
            cookie_value = (cookie_value === 2) ? -2 : 2;
        }  
        SCHLIX.Cookie.remove(cookie_name);
        SCHLIX.Cookie.set(cookie_name, cookie_value, {path: "/"});
         

        var class_to_set = SCHLIX.Dom.get('{.' + container_class + '}');
        var the_style = (cookie_value === 2) ? 'block' : 'none';
        var the_opacity = (cookie_value === 2) ? 1 : 0;
        for (var i = 0; i < class_to_set.length;i++)
        {
            class_to_set[i].style.opacity = the_opacity;
            class_to_set[i].style.display = the_style;
        }
        if (indicator != null)
            indicator.className = (cookie_value === 2) ? 'fa fa-check-circle whatsappchat-green' : 'fa fa-square whatsappchat-gray';
        return false;    
    };
    toggleShowBar()
    {
        this.toggleControl('',  'whatsappchat_showhide',   'whatsappchat-bar');
        return false;
    };

    sendWhatsAppMessage(e)
    {
        var phone_number = SCHLIX.Dom.get('whatsappchat-phonenumber').getAttribute('data-phone');
        var message = SCHLIX.Dom.get('whatsappchat-message').value;
        var div_error = SCHLIX.Dom.get('whatsappchat-error-msg');
        var str_error = '';
        if (phone_number.trim() == '')
        {
            div_error.innerHTML = 'The phone number is not configured yet';
            div_error.className = 'alert alert-danger';            
        } else if (message.trim() == '')
        {
            div_error.innerHTML = 'Please type your message before sending';
            div_error.className = 'alert alert-danger';
        } else
        {
            var encoded_message = encodeURI(message.trim());
            div_error.innerHTML = '';
            div_error.className = '';

            var whatsapp_url_prefix = (SCHLIX.Core.ua.mobile === null) ? 'web' : 'api';
            var url = 'https://' + whatsapp_url_prefix + '.whatsapp.com/send?phone=' + phone_number + '&text=' + encoded_message;
            window.open(url,'_blank');
            SCHLIX.Dom.get('whatsappchat-message').innerHTML = '';
            this.toggleShowBar();
        }
    };
};

SCHLIX.Event.onDOMReady(
    
function ()
{
    var __whatsapp_chat = new SCHLIX.CMS_WhatsAppChat();
}  
    
);